"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runLessToCssVariables = void 0;
const generate_1 = require("./generate");
const rules_1 = require("./rules");
const reduction_1 = require("./reduction");
const resolve_1 = require("./utils/resolve");
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const variables_1 = require("./generate/variables");
function runLessToCssVariables({ cwd = process.cwd(), revert = false, force = false, verbose = false, libraryList = [], series = 'ant-design', } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const libEntry = (0, resolve_1.resolveLibraryList)(libraryList);
        yield Promise.all(libEntry.map((libraryDir, index) => __awaiter(this, void 0, void 0, function* () {
            const libraryItem = libraryList[index];
            createDefaultOptions(series, libraryItem);
            const rules = yield (0, rules_1.buildRules)(libraryItem, series, force);
            const opts = {
                cwd,
                force,
                revert,
                verbose,
                libraryDir,
                libraryItem,
                joinFullPath: (...paths) => path_1.default.join(libraryDir, ...paths),
            };
            try {
                if (revert) {
                    return (0, reduction_1.runReductions)(rules, opts).then(() => {
                        console.info(` Restore the ${chalk_1.default.cyan(libraryItem.name)} style variable file successfully`);
                    });
                }
                // 执行修改、覆盖
                return (0, generate_1.generateCoverages)(rules, opts).then(() => {
                    console.info(`Successfully overwrite and modify the ${chalk_1.default.cyan(libraryItem.name)} style variable file`);
                });
            }
            catch (error) {
                console.error(`[preprocess-less-to-css-variable]: ${error.toString()}`);
            }
        })));
        // 处理变量，写入缓存
        yield (0, variables_1.generateVariables)();
    });
}
exports.runLessToCssVariables = runLessToCssVariables;
function createDefaultOptions(seriesType, libraryItem) {
    if (seriesType === 'ant-design') {
        if (!libraryItem.includes || libraryItem.includes.length === 0) {
            libraryItem.includes = ['lib', 'es'];
        }
    }
}
